import os
import json
import grpc
from time import time
from datetime import date
from google.protobuf.json_format import MessageToDict
from willowlabs.tools import tools, protobuffer_tools as pb_tools
from willowlabs.service_grpc.company_information import company_information_service_pb2 as pb2, \
    company_information_service_pb2_grpc as pb2_grpc
from typing import Any, Optional, Union
from functools import wraps


def _check_jwt(f):
    @wraps(f)
    def wrapped_function(self, *args, **kwargs):
        if self.jwt is None or self.jwt_expires is None or self.jwt_expires < time():
            self.get_json_web_token()
        return f(self, *args, **kwargs)
    return wrapped_function


class CompanyInformationClient:
    """
    Class to access Willow Labs API.
    """

    def __init__(self, configuration_path: str, **kwargs: Any):
        """
        Initialize the client.
        Args:
            configuration_path: The path of the configuration file.
            **kwargs: Extra arguments.
        """
        self.configuration_path = configuration_path
        self.configuration = None
        self.service_type = kwargs.get("service_type", "production")
        self.credentials_info = None
        self.host = None
        self.issuer = None
        self.audiences = None
        self.jwt = None
        self.jwt_expires = None
        self.api_key = None
        self.timeout = kwargs.get("timeout", 120)        # Seconds
        self.scopes = ["https://www.googleapis.com/auth/cloud-platform"]
        self.return_dict = kwargs.get("return_dict", False)

    def load_configuration(self):
        """
        Loads the configuration into memory.
        """
        self.configuration = tools.load_client_configuration(self.configuration_path)
        self.host = self.configuration["service"][self.service_type]["host"]
        self.issuer = self.configuration["service"][self.service_type]["authentication"]["issuer"]
        self.audiences = self.configuration["service"][self.service_type]["authentication"]["audiences"]
        self.api_key = self.configuration["service"][self.service_type]["api_key"]

    def load_credentials(self):
        """
        Loads the credentials into memory.
        """
        if self.configuration is None:
            self.load_configuration()
        configuration = self.configuration["service"][self.service_type]
        path = configuration["service_account_credentials"]
        if path.endswith(".json") and os.path.exists(path):
            with open(path, "r") as fp:
                self.credentials_info = json.load(fp)
        else:
            raise FileNotFoundError(f"Unable to find credentials in path {path}.")

    def get_json_web_token(self):
        """
        Loads the web token into memory Uses impersonation of Willowlabs service account by currently signed in service account.
        This will enable the current service account to behave as if it was logged in as Willow Labs API service account. Billing for billable requests to gcloud will be billed to current service account.
        """
        if self.credentials_info is None:
            self.load_credentials()
        token, expires = tools.generate_jwt_token_from_impersonated_account(self.credentials_info, self.audiences,
                                                                            self.issuer)
        self.jwt = token
        self.jwt_expires = expires

    @_check_jwt
    def get_company_ownership(self, organisation_number: int, record_year: int, depth: int = 25, cutoff: float = 1.0,
                              top: int = 0) -> pb2.OwnershipResponse:
        """
        Get owners for a company.
        Args:
            organisation_number: The organization number for the company being queried.
            record_year: The ownership year.
            depth: Max depth of ownership structure returned.
            cutoff: Minimum percentage of ownership for inclusion in result.
            top: The number of max elements returned (The top N owners).
        Returns:
            The ownership structure.
        """
        with grpc.secure_channel(self.host, grpc.ssl_channel_credentials()) as channel:
            stub = pb2_grpc.CompanyInformationStub(channel)
            metadata = [("authorization", f"Bearer {self.jwt}"), ("x-api-key", self.api_key)]
            request = pb2.OwnershipRequest(organisation_number=organisation_number, record_year=record_year,
                                           depth=depth, cutoff=cutoff, top=top)
            ownership_information = stub.get_company_ownership(request, self.timeout, metadata=metadata)
        return MessageToDict(ownership_information) if self.return_dict else ownership_information

    @_check_jwt
    def get_company_roles(self, organisation_number: int, query_date: Optional[date] = None) -> pb2.RoleResponse:
        """
        Get the roles for a company.
        Args:
            organisation_number: The organization number for the company being queried.
            query_date: Information retrieved will be the one valid at this date.

        Returns:
            The roles belonging to the given organization number.
        """
        with grpc.secure_channel(self.host, grpc.ssl_channel_credentials()) as channel:
            stub = pb2_grpc.CompanyInformationStub(channel)
            metadata = [("authorization", f"Bearer {self.jwt}"), ("x-api-key", self.api_key)]
            request = pb2.RoleRequest(organisation_number=organisation_number,
                                      query_date=pb_tools.date_to_pb2_date(query_date))
            roles = stub.get_company_roles(request, self.timeout, metadata=metadata)
        return MessageToDict(roles) if self.return_dict else roles

    @_check_jwt
    def get_basic_company_information(self, organisation_number: int,
                                      query_date: Optional[date] = None) -> pb2.BasicCompanyInformationResponse:
        """
        Get the basic information for a company. May include address, industrikode (industry code), næringskode (business code).
        Args:
            organisation_number: The organization number for the company being queried.
            query_date: Information retrieved will be the one valid at this date.

        Returns:
            The the basic information of the organization number given.
        """
        with grpc.secure_channel(self.host, grpc.ssl_channel_credentials()) as channel:
            stub = pb2_grpc.CompanyInformationStub(channel)
            metadata = [("authorization", f"Bearer {self.jwt}"), ("x-api-key", self.api_key)]
            request = pb2.BasicCompanyInformationRequest(organisation_number=organisation_number,
                                                         query_date=pb_tools.date_to_pb2_date(query_date))
            results = stub.get_basic_company_information(request, self.timeout, metadata=metadata)
        return MessageToDict(results) if self.return_dict else results

    @_check_jwt
    def _get_company_signatory_information(self, organisation_number: int,
                                           authority_type: Union[str, int],
                                           query_date: Optional[date] = None) -> pb2.SignatoryInformationResponse:
        """
        Get the authority holders for the company for a given authority type.
        Args:
            organisation_number: The organization number for the company being queried.
            authority_type: The authority type being requested.
            query_date: Information retrieved will be the one valid at this date.

        Returns:
            The signature holders of the given organization number.
        """
        if isinstance(authority_type, str):
            try:
                authority_type = getattr(pb2.SignatoryAuthorityTypes, authority_type.upper())
            except AttributeError:
                raise ValueError(f"Unknown authority type '{authority_type}'. Authority type must be among "
                                 f"'POWER_OF_ATTORNEY', 'PROKURA', 'FULL_SIGNATORY_AUTHORITY', or 'SIGNATUR'.")

        if authority_type == pb2.SignatoryAuthorityTypes.UNKNOWN_AUTHORITY:
            raise ValueError(f"Authority type may not be UNKNOWN_AUTHORITY.")

        with grpc.secure_channel(self.host, grpc.ssl_channel_credentials()) as channel:
            stub = pb2_grpc.CompanyInformationStub(channel)
            metadata = [("authorization", f"Bearer {self.jwt}"), ("x-api-key", self.api_key)]
            request = pb2.SignatoryInformationRequest(organisation_number=organisation_number,
                                                      authority_type=authority_type,
                                                      query_date=pb_tools.date_to_pb2_date(query_date))
            results = stub.get_company_signatory_information(request, self.timeout, metadata=metadata)
        return MessageToDict(results) if self.return_dict else results

    @_check_jwt
    def get_company_power_of_attorney(self, organisation_number: int,
                                      query_date: Optional[date] = None) -> pb2.SignatoryInformationResponse:
        """
        Get the power of attorney (prokura) for the company. Power of attorney is the signature rights for all daily operations.
        See (in Norwegian): `Lovdata <https://lovdata.no/dokument/NL/lov/1985-06-21-80>`_ or `Wikipedia <https://no.wikipedia.org/wiki/Prokura>`_.

        English version of :func:`~willowlabs.company_information.client.CompanyInformationClient.get_company_prokura`.

        Args:
            organisation_number: The organization number for the company being queried.
            query_date: Information retrieved will be the one valid at this date.

        Returns:
            The list of all the the power of attorney rights.
        """
        return self._get_company_signatory_information(organisation_number,
                                                       pb2.SignatoryAuthorityTypes.POWER_OF_ATTORNEY,
                                                       query_date=query_date)

    @_check_jwt
    def get_company_full_signatory_authority(self, organisation_number: int,
                                             query_date: Optional[date] = None) -> pb2.SignatoryInformationResponse:
        """
        Get the signature holders for a company. Signature is the right to sign for the companies in all situations.
        Extension of prokura which is only for daily operations.

        English version of :func:`~willowlabs.company_information.client.CompanyInformationClient.get_company_signatur`.

        Args:
            organisation_number: The organization number for the company being queried.
            query_date: The date to get the signature for.

        Returns:
            The signature holders.
        """
        return self._get_company_signatory_information(organisation_number,
                                                       pb2.SignatoryAuthorityTypes.FULL_SIGNATORY_AUTHORITY,
                                                       query_date=query_date)

    @_check_jwt
    def get_company_prokura(self, organisation_number: int,
                            query_date: Optional[date] = None) -> pb2.SignatoryInformationResponse:
        """
        Get the prokura rights for the company. Prokura is the signature rights for all daily operations.
        See: `Lovdata <https://lovdata.no/dokument/NL/lov/1985-06-21-80>`_ or `Wikipedia <https://no.wikipedia.org/wiki/Prokura>`_.

        Norwegian version of :func:`~willowlabs.company_information.client.CompanyInformationClient.get_company_power_of_attorney`.

        Args:
            organisation_number: The organization number for the company being queried.
            query_date: Information retrieved will be the one valid at this date.

        Returns:
            The list of all prokuras.
        """
        return self._get_company_signatory_information(organisation_number,
                                                       pb2.SignatoryAuthorityTypes.PROKURA,
                                                       query_date=query_date)

    @_check_jwt
    def get_company_signatur(self, organisation_number: int,
                             query_date: Optional[date] = None) -> pb2.SignatoryInformationResponse:
        """
        Get the signature holders for a company. Signature is the right to sign for the companies in all situations.
        Extension of prokura which is only for daily operations.

        Norwegian version of :func:`~willowlabs.company_information.client.CompanyInformationClient.get_company_full_signatory_authority`.

        Args:
            organisation_number: The organization number for the company being queried.
            query_date: The date to get the signature for.

        Returns:
            The signature holders.
        """
        return self._get_company_signatory_information(organisation_number,
                                                       pb2.SignatoryAuthorityTypes.SIGNATUR,
                                                       query_date=query_date)



from willowlabs.company_information.client import CompanyInformationClient
import datetime as dt
import csv


org_list = [
    917813752,
    917813817,
    917813825,
    917813833,
    917813876,
    917813884,
    917813906,
    917813930,
    917814015,
    917814090,
    917814120,
    917814201,
    917814333,
    917814597,
    917814694,
    917814708,
    917814783,
    917814880,
    917814899,
    917814929,
    917815038,
    917815186,
    917815283,
    917815429,
    917815461,
    917815593,
    917815704,
    917815771,
    917815801,
    917815860,
    917815909,
    917816085,
    917816212,
    917816328,
    917816379,
    917816387,
    917816425,
    917816581,
    917816638,
    917816662,
    917816697,
    917816727,
    917816808,
    917816816,
    917816891,
    917816980,
    917817014,
    917817448,
    917817464,
    917817561,
    917817588,
    917817936,
    917818061,
    917818088,
    917818096,
    917818118,
    917818355,
    917818843,
    917818851,
    917818908,
    917818983,
    917819009,
    917819041,
    917819068,
    917819084,
    917819149,
    917819238,
    917819262,
]

org_list = [
    917813752,
]


def run_report(org_list=org_list):
    import pandas as pd

    client = CompanyInformationClient("C:\\Users\\Sven\\projects\\client_config.yaml")

    roles_error_list = []
    # shares_error_list = []
    # basic_error_list = []
    # prokura_error_list = []
    # signature_error_list = []

    for org in org_list:
        result = client.get_company_roles(org, query_date=dt.datetime.today())
        print(result)
        roles_error_list.append([org, result.server_error])
        # result = client.get_basic_company_information(org)
        # basic_error_list.append([org, result.server_error])
        # result = client.get_company_ownership(org, record_year=dt.datetime.today().year)
        # shares_error_list.append([org, result.server_error])

    roller_df = pd.DataFrame(
        roles_error_list, columns=["Organisation Number", "Result"]
    )
    roller_df.insert(0, "Test case no.", roller_df.index)
    # roller_df['Test case no.'] = roller_df.index
    generate_report(roller_df)


def generate_report(roller_df=None):
    from pathlib import Path
    from jinja2 import Environment, FileSystemLoader

    import pandas as pd

    # roller_df = pd.DataFrame([[121212, 'Y'], [5555, 'N']])

    template_vars = {
        "title": "Test Suite Report - All endpoints",
        "roller_table": "ssdsadasd" + roller_df.to_html(index=False),
    }
    data_folder = Path("")
    file_to_open = data_folder / "testreport.html"
    env = Environment(loader=FileSystemLoader("."), autoescape=True)

    template = env.get_template(str(file_to_open))
    html_out = template.render(template_vars)
    print(html_out)

    # with open("../testing_out.csv", "w", newline="") as f:
    #     writer = csv.writer(f)
    #     writer.writerows(roles_error_list)

    Html_file = open("test_result.html", "w")
    Html_file.write(html_out)
    Html_file.close()


generate_report(None)



from google.protobuf.json_format import MessageToDict
from datetime import date, datetime
from typing import Any, Dict, Optional, Union
from willowlabs.service_grpc.company_information import company_information_service_pb2 as pb2


def date_to_pb2_date(d: Union[date, datetime, None]) -> Optional[pb2.Date]:
    if d is None:
        return None
    return pb2.Date(year=d.year, month=d.month, day=d.day)


def to_dict(message, **kwargs: Any) -> Union[Dict[str, Any], date, datetime]:
    class_name = str(message.__class___)[8:-2]
    if class_name.endswith(".Date"):
        return date(year=message.year, month=message.month, day=message.day)
    if class_name.endswith(".Timestamp"):
        return datetime(year=message.year, month=message.month, day=message.day, hour=message.hour,
                        minute=message.minute, second=message.second, microsecond=message.microsecond)
    return MessageToDict(message, **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: willowlabs/service_grpc/company_information/company_information_service.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='willowlabs/service_grpc/company_information/company_information_service.proto',
  package='willowlabs.services.company_information',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\nMwillowlabs/service_grpc/company_information/company_information_service.proto\x12\'willowlabs.services.company_information\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\x0f\x44irectOwnership\x12\x0e\n\x06shares\x18\x01 \x01(\x03\x12H\n\x0bshare_class\x18\x02 \x01(\x0e\x32\x33.willowlabs.services.company_information.ShareClass\"\x89\x02\n\x0fIndividualOwner\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nbirth_year\x18\x02 \x01(\x05\x12\x13\n\x0bpostal_code\x18\x03 \x01(\t\x12\x13\n\x0bpostal_city\x18\x04 \x01(\t\x12\x15\n\rpercent_share\x18\x05 \x01(\x02\x12\x19\n\x11\x65quivalent_shares\x18\x06 \x01(\x02\x12\x11\n\tmin_depth\x18\x07 \x01(\x05\x12\x11\n\tmax_depth\x18\x08 \x01(\x05\x12R\n\x10\x64irect_ownership\x18\t \x03(\x0b\x32\x38.willowlabs.services.company_information.DirectOwnership\"\xbe\x01\n\x0cUnknownOwner\x12\x13\n\x0bpostal_code\x18\x01 \x01(\t\x12\x13\n\x0bpostal_city\x18\x02 \x01(\t\x12\x15\n\rpercent_share\x18\x03 \x01(\x02\x12\x19\n\x11\x65quivalent_shares\x18\x04 \x01(\x02\x12R\n\x10\x64irect_ownership\x18\x05 \x03(\x0b\x32\x38.willowlabs.services.company_information.DirectOwnership\"\x84\x01\n\x10OwnershipRequest\x12\x1b\n\x13organisation_number\x18\x01 \x01(\x05\x12\x13\n\x0brecord_year\x18\x02 \x01(\x05\x12\x0e\n\x06\x63utoff\x18\x03 \x01(\x02\x12\r\n\x05\x64\x65pth\x18\x04 \x01(\x05\x12\x0b\n\x03top\x18\x05 \x01(\x05\x12\x12\n\nexhaustive\x18\x06 \x01(\x08\"\x9e\x02\n\rCompanyShares\x12\x1b\n\x13organisation_number\x18\x01 \x01(\x05\x12\x14\n\x0c\x63ompany_name\x18\x02 \x01(\t\x12\x0c\n\x04isin\x18\x03 \x01(\t\x12\x14\n\x0ctotal_shares\x18\x04 \x01(\x03\x12S\n\x11individual_owners\x18\x05 \x03(\x0b\x32\x38.willowlabs.services.company_information.IndividualOwner\x12M\n\x0eunknown_owners\x18\x06 \x03(\x0b\x32\x35.willowlabs.services.company_information.UnknownOwner\x12\x12\n\nexhaustive\x18\x07 \x01(\x08\"\x92\x02\n\x11OwnershipResponse\x12J\n\x07request\x18\x01 \x01(\x0b\x32\x39.willowlabs.services.company_information.OwnershipRequest\x12N\n\x0e\x63ompany_shares\x18\x02 \x03(\x0b\x32\x36.willowlabs.services.company_information.CompanyShares\x12\x13\n\x0b\x62\x61\x64_request\x18\x03 \x01(\x08\x12\x14\n\x0cserver_error\x18\x04 \x01(\x08\x12\x36\n\x12response_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"0\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"m\n\x0bRoleRequest\x12\x1b\n\x13organisation_number\x18\x01 \x01(\x05\x12\x41\n\nquery_date\x18\x02 \x01(\x0b\x32-.willowlabs.services.company_information.Date\"U\n\x07\x41\x64\x64ress\x12\x16\n\x0estreet_address\x18\x01 \x01(\t\x12\x0c\n\x04\x63ity\x18\x02 \x01(\t\x12\x13\n\x0bpostal_code\x18\x03 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x04 \x01(\t\"\xbc\x04\n\x0e\x43ompanyOfficer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nbirth_year\x18\x02 \x01(\x05\x12\x44\n\rdate_of_birth\x18\t \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12\x1b\n\x13organisation_number\x18\x08 \x01(\x05\x12\x41\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x30.willowlabs.services.company_information.Address\x12;\n\x04role\x18\x04 \x01(\x0e\x32-.willowlabs.services.company_information.Role\x12J\n\x0cspecial_role\x18\x05 \x01(\x0e\x32\x34.willowlabs.services.company_information.SpecialRole\x12H\n\x0brole_action\x18\x06 \x01(\x0e\x32\x33.willowlabs.services.company_information.RoleAction\x12H\n\x11\x61nnouncement_date\x18\x07 \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12\x11\n\tis_person\x18\n \x01(\x08\x12\x19\n\x11\x62\x61\x64_date_of_birth\x18\x0b \x01(\x08\x12\x17\n\x0fraw_date_string\x18\x0c \x01(\t\"\xbf\x02\n\x0cRoleResponse\x12\x45\n\x07request\x18\x01 \x01(\x0b\x32\x34.willowlabs.services.company_information.RoleRequest\x12I\n\x08officers\x18\x02 \x03(\x0b\x32\x37.willowlabs.services.company_information.CompanyOfficer\x12\x1b\n\x13\x63omplete_ceo_search\x18\x03 \x01(\x08\x12\x1d\n\x15\x63omplete_board_search\x18\x04 \x01(\x08\x12\x13\n\x0b\x62\x61\x64_request\x18\x05 \x01(\x08\x12\x14\n\x0cserver_error\x18\x06 \x01(\x08\x12\x36\n\x12response_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"J\n\nSectorCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65scription_en\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65scription_nb\x18\x03 \x01(\t\"\x94\x03\n\x08NACECode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x65scription_en\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65scription_nb\x18\x03 \x01(\t\x12\x13\n\x0blevel1_code\x18\x04 \x01(\t\x12\x1d\n\x15level1_description_en\x18\x05 \x01(\t\x12\x1d\n\x15level1_description_nb\x18\x06 \x01(\t\x12\x13\n\x0blevel2_code\x18\x07 \x01(\t\x12\x1d\n\x15level2_description_en\x18\x08 \x01(\t\x12\x1d\n\x15level2_description_nb\x18\t \x01(\t\x12\x13\n\x0blevel3_code\x18\n \x01(\t\x12\x1d\n\x15level3_description_en\x18\x0b \x01(\t\x12\x1d\n\x15level3_description_nb\x18\x0c \x01(\t\x12\x13\n\x0blevel4_code\x18\r \x01(\t\x12\x1d\n\x15level4_description_en\x18\x0e \x01(\t\x12\x1d\n\x15level4_description_nb\x18\x0f \x01(\t\"K\n\x0b\x43ompanyType\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x65scription_en\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65scription_nb\x18\x03 \x01(\t\"\x8a\x01\n\x15NonprofitRegistration\x12\x1f\n\x17registered_as_nonprofit\x18\x01 \x01(\x08\x12\'\n\x1fvat_registration_description_en\x18\x02 \x03(\t\x12\'\n\x1fvat_registration_description_nb\x18\x03 \x03(\t\"\x99\x01\n\x0e\x43ompanyAddress\x12\x16\n\x0estreet_address\x18\x01 \x03(\t\x12\x0c\n\x04\x63ity\x18\x02 \x01(\t\x12\x13\n\x0bpostal_code\x18\x03 \x01(\t\x12\x0e\n\x06\x63ounty\x18\x04 \x01(\t\x12\x15\n\rcounty_number\x18\x05 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x06 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x07 \x01(\t\"\xd1\x0c\n\x17\x42\x61sicCompanyInformation\x12\x1b\n\x13organisation_number\x18\x01 \x01(\x05\x12\x14\n\x0c\x63ompany_name\x18\x02 \x01(\t\x12\x43\n\x0c\x66ounded_date\x18\x03 \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12H\n\x11registration_date\x18\x04 \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12J\n\x0c\x63ompany_type\x18\x05 \x01(\x0b\x32\x34.willowlabs.services.company_information.CompanyType\x12\x0f\n\x07website\x18\x06 \x01(\t\x12^\n\x16nonprofit_registration\x18\x07 \x01(\x0b\x32>.willowlabs.services.company_information.NonprofitRegistration\x12\"\n\x1aregistered_in_vat_registry\x18\x08 \x01(\x08\x12\'\n\x1fregistered_in_business_registry\x18\t \x01(\x08\x12)\n!registered_in_foundation_registry\x18\n \x01(\x08\x12\x1b\n\x13number_of_employees\x18\x0b \x01(\x05\x12V\n\x19institutional_sector_code\x18\x0c \x01(\x0b\x32\x33.willowlabs.services.company_information.SectorCode\x12J\n\x0findustry_code_1\x18\r \x01(\x0b\x32\x31.willowlabs.services.company_information.NACECode\x12J\n\x0findustry_code_2\x18\x0e \x01(\x0b\x32\x31.willowlabs.services.company_information.NACECode\x12J\n\x0findustry_code_3\x18\x0f \x01(\x0b\x32\x31.willowlabs.services.company_information.NACECode\x12O\n\x0epostal_address\x18\x10 \x01(\x0b\x32\x37.willowlabs.services.company_information.CompanyAddress\x12Q\n\x10\x62usiness_address\x18\x11 \x01(\x0b\x32\x37.willowlabs.services.company_information.CompanyAddress\x12&\n\x1elast_submitted_annual_accounts\x18\x12 \x01(\x05\x12\x10\n\x08\x62\x61nkrupt\x18\x13 \x01(\x08\x12\x19\n\x11under_liquidation\x18\x14 \x01(\x08\x12/\n\'under_forced_liquidation_or_dissolution\x18\x15 \x01(\x08\x12\x16\n\x0eparent_company\x18\x16 \x01(\x05\x12\x10\n\x08language\x18\x17 \x01(\t\x12H\n\x11\x63ommencement_date\x18\x18 \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12\x43\n\x0c\x63losure_date\x18\x19 \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12\x45\n\x0eownership_date\x18\x1a \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12Q\n\x10location_address\x18\x1b \x01(\x0b\x32\x37.willowlabs.services.company_information.CompanyAddress\x12M\n\x16record_first_retrieved\x18\x1c \x01(\x0b\x32-.willowlabs.services.company_information.Date\x12\x1a\n\x12most_recent_record\x18\x1d \x01(\x08\"\x80\x01\n\x1e\x42\x61sicCompanyInformationRequest\x12\x1b\n\x13organisation_number\x18\x01 \x01(\x05\x12\x41\n\nquery_date\x18\x02 \x01(\x0b\x32-.willowlabs.services.company_information.Date\"\xc3\x02\n\x1f\x42\x61sicCompanyInformationResponse\x12X\n\x07request\x18\x01 \x01(\x0b\x32G.willowlabs.services.company_information.BasicCompanyInformationRequest\x12\x63\n\x19\x62\x61sic_company_information\x18\x02 \x01(\x0b\x32@.willowlabs.services.company_information.BasicCompanyInformation\x12\x13\n\x0b\x62\x61\x64_request\x18\x03 \x01(\x08\x12\x14\n\x0cserver_error\x18\x04 \x01(\x08\x12\x36\n\x12response_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"i\n\x13SignatoryIndividual\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\rdate_of_birth\x18\x02 \x01(\x0b\x32-.willowlabs.services.company_information.Date\"\xd7\x01\n\x1bSignatoryInformationRequest\x12\x1b\n\x13organisation_number\x18\x01 \x01(\x05\x12X\n\x0e\x61uthority_type\x18\x02 \x01(\x0e\x32@.willowlabs.services.company_information.SignatoryAuthorityTypes\x12\x41\n\nquery_date\x18\x03 \x01(\x0b\x32-.willowlabs.services.company_information.Date\"\xb6\x01\n\x13\x41uthorizedSignature\x12\x19\n\x11signatory_text_nb\x18\x01 \x01(\t\x12\x19\n\x11signatory_text_en\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12[\n\x15\x61uthorized_individual\x18\x04 \x01(\x0b\x32<.willowlabs.services.company_information.SignatoryIndividual\"\x8f\x03\n\x1cSignatoryInformationResponse\x12U\n\x07request\x18\x01 \x01(\x0b\x32\x44.willowlabs.services.company_information.SignatoryInformationRequest\x12[\n\x15\x61uthorized_signatures\x18\x02 \x03(\x0b\x32<.willowlabs.services.company_information.AuthorizedSignature\x12\x1a\n\x12raw_signatory_text\x18\x03 \x01(\t\x12\"\n\x1ano_signatory_records_found\x18\x04 \x01(\x08\x12\x18\n\x10\x66\x61llback_results\x18\x05 \x01(\x08\x12\x13\n\x0b\x62\x61\x64_request\x18\x06 \x01(\x08\x12\x14\n\x0cserver_error\x18\x07 \x01(\x08\x12\x36\n\x12response_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*\xe9\x01\n\nShareClass\x12\x17\n\x13UNKNOWN_SHARE_CLASS\x10\x00\x12\x13\n\x0fORDINARY_SHARES\x10\x01\x12\x0b\n\x07\x43LASS_A\x10\x02\x12\x0b\n\x07\x43LASS_B\x10\x03\x12\x0b\n\x07\x43LASS_C\x10\x04\x12\x0b\n\x07\x43LASS_D\x10\x05\x12\x0b\n\x07\x43LASS_E\x10\x06\x12\x0b\n\x07\x43LASS_F\x10\x07\x12\x0b\n\x07\x43LASS_G\x10\x08\x12\x0b\n\x07\x43LASS_H\x10\t\x12\x0b\n\x07\x43LASS_I\x10\n\x12\x14\n\x10PREFERRED_SHARES\x10\x0b\x12\x18\n\x14\x45XTRAORDINARY_SHARES\x10\x0c\x12\x08\n\x04ISIN\x10\r*\xdc\x02\n\x04Role\x12\x10\n\x0cUNKNOWN_ROLE\x10\x00\x12\x07\n\x03\x43\x45O\x10\x01\x12\x0c\n\x08\x43HAIRMAN\x10\x02\x12\x13\n\x0f\x44\x45PUTY_CHAIRMAN\x10\x03\x12\x10\n\x0c\x42OARD_MEMBER\x10\x04\x12\x17\n\x13\x44\x45PUTY_BOARD_MEMBER\x10\x05\x12\x0e\n\nPROPRIETOR\x10\x06\x12\x12\n\x0e\x43ONTACT_PERSON\x10\x07\x12\x0b\n\x07MANAGER\x10\x08\x12\x0e\n\nACCOUNTANT\x10\t\x12\x0b\n\x07TRUSTEE\x10\n\x12\x1c\n\x18NORWEGIAN_REPRESENTATIVE\x10\x0b\x12\x0b\n\x07\x41UDITOR\x10\x0c\x12\x0c\n\x08OBSERVER\x10\r\x12#\n\x1fPARTICIPANT_FULL_RESPONSIBILITY\x10\x0e\x12#\n\x1fPARTICIPANT_PART_RESPONSIBILITY\x10\x0f\x12\x1a\n\x16\x41LTERNATE_BOARD_MEMBER\x10\x10*[\n\x0bSpecialRole\x12\x13\n\x0fNO_SPECIAL_ROLE\x10\x00\x12\x1b\n\x17\x45MPLOYEE_REPRESENTATIVE\x10\x01\x12\x1a\n\x16\x41_SHARE_REPRESENTATIVE\x10\x02*6\n\nRoleAction\x12\r\n\tNO_ACTION\x10\x00\x12\x0c\n\x08RESIGNED\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02*\x80\x01\n\x17SignatoryAuthorityTypes\x12\x15\n\x11UNKNOWN_AUTHORITY\x10\x00\x12\x15\n\x11POWER_OF_ATTORNEY\x10\x01\x12\x0b\n\x07PROKURA\x10\x02\x12\x1c\n\x18\x46ULL_SIGNATORY_AUTHORITY\x10\x03\x12\x0c\n\x08SIGNATUR\x10\x04\x32\x98\x05\n\x12\x43ompanyInformation\x12\x90\x01\n\x15get_company_ownership\x12\x39.willowlabs.services.company_information.OwnershipRequest\x1a:.willowlabs.services.company_information.OwnershipResponse\"\x00\x12\x82\x01\n\x11get_company_roles\x12\x34.willowlabs.services.company_information.RoleRequest\x1a\x35.willowlabs.services.company_information.RoleResponse\"\x00\x12\xb4\x01\n\x1dget_basic_company_information\x12G.willowlabs.services.company_information.BasicCompanyInformationRequest\x1aH.willowlabs.services.company_information.BasicCompanyInformationResponse\"\x00\x12\xb2\x01\n!get_company_signatory_information\x12\x44.willowlabs.services.company_information.SignatoryInformationRequest\x1a\x45.willowlabs.services.company_information.SignatoryInformationResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_SHARECLASS = _descriptor.EnumDescriptor(
  name='ShareClass',
  full_name='willowlabs.services.company_information.ShareClass',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SHARE_CLASS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINARY_SHARES', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_A', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_B', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_C', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_D', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_E', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_F', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_G', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_H', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLASS_I', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREFERRED_SHARES', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTRAORDINARY_SHARES', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ISIN', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6418,
  serialized_end=6651,
)
_sym_db.RegisterEnumDescriptor(_SHARECLASS)

ShareClass = enum_type_wrapper.EnumTypeWrapper(_SHARECLASS)
_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='willowlabs.services.company_information.Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ROLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CEO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAIRMAN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPUTY_CHAIRMAN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOARD_MEMBER', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPUTY_BOARD_MEMBER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROPRIETOR', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTACT_PERSON', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MANAGER', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCOUNTANT', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRUSTEE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NORWEGIAN_REPRESENTATIVE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDITOR', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OBSERVER', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_FULL_RESPONSIBILITY', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_PART_RESPONSIBILITY', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALTERNATE_BOARD_MEMBER', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6654,
  serialized_end=7002,
)
_sym_db.RegisterEnumDescriptor(_ROLE)

Role = enum_type_wrapper.EnumTypeWrapper(_ROLE)
_SPECIALROLE = _descriptor.EnumDescriptor(
  name='SpecialRole',
  full_name='willowlabs.services.company_information.SpecialRole',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_SPECIAL_ROLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMPLOYEE_REPRESENTATIVE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='A_SHARE_REPRESENTATIVE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7004,
  serialized_end=7095,
)
_sym_db.RegisterEnumDescriptor(_SPECIALROLE)

SpecialRole = enum_type_wrapper.EnumTypeWrapper(_SPECIALROLE)
_ROLEACTION = _descriptor.EnumDescriptor(
  name='RoleAction',
  full_name='willowlabs.services.company_information.RoleAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_ACTION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESIGNED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7097,
  serialized_end=7151,
)
_sym_db.RegisterEnumDescriptor(_ROLEACTION)

RoleAction = enum_type_wrapper.EnumTypeWrapper(_ROLEACTION)
_SIGNATORYAUTHORITYTYPES = _descriptor.EnumDescriptor(
  name='SignatoryAuthorityTypes',
  full_name='willowlabs.services.company_information.SignatoryAuthorityTypes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_AUTHORITY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POWER_OF_ATTORNEY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROKURA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL_SIGNATORY_AUTHORITY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNATUR', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7154,
  serialized_end=7282,
)
_sym_db.RegisterEnumDescriptor(_SIGNATORYAUTHORITYTYPES)

SignatoryAuthorityTypes = enum_type_wrapper.EnumTypeWrapper(_SIGNATORYAUTHORITYTYPES)
UNKNOWN_SHARE_CLASS = 0
ORDINARY_SHARES = 1
CLASS_A = 2
CLASS_B = 3
CLASS_C = 4
CLASS_D = 5
CLASS_E = 6
CLASS_F = 7
CLASS_G = 8
CLASS_H = 9
CLASS_I = 10
PREFERRED_SHARES = 11
EXTRAORDINARY_SHARES = 12
ISIN = 13
UNKNOWN_ROLE = 0
CEO = 1
CHAIRMAN = 2
DEPUTY_CHAIRMAN = 3
BOARD_MEMBER = 4
DEPUTY_BOARD_MEMBER = 5
PROPRIETOR = 6
CONTACT_PERSON = 7
MANAGER = 8
ACCOUNTANT = 9
TRUSTEE = 10
NORWEGIAN_REPRESENTATIVE = 11
AUDITOR = 12
OBSERVER = 13
PARTICIPANT_FULL_RESPONSIBILITY = 14
PARTICIPANT_PART_RESPONSIBILITY = 15
ALTERNATE_BOARD_MEMBER = 16
NO_SPECIAL_ROLE = 0
EMPLOYEE_REPRESENTATIVE = 1
A_SHARE_REPRESENTATIVE = 2
NO_ACTION = 0
RESIGNED = 1
EXPIRED = 2
UNKNOWN_AUTHORITY = 0
POWER_OF_ATTORNEY = 1
PROKURA = 2
FULL_SIGNATORY_AUTHORITY = 3
SIGNATUR = 4



_DIRECTOWNERSHIP = _descriptor.Descriptor(
  name='DirectOwnership',
  full_name='willowlabs.services.company_information.DirectOwnership',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shares', full_name='willowlabs.services.company_information.DirectOwnership.shares', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='share_class', full_name='willowlabs.services.company_information.DirectOwnership.share_class', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=262,
)


_INDIVIDUALOWNER = _descriptor.Descriptor(
  name='IndividualOwner',
  full_name='willowlabs.services.company_information.IndividualOwner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='willowlabs.services.company_information.IndividualOwner.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='birth_year', full_name='willowlabs.services.company_information.IndividualOwner.birth_year', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='willowlabs.services.company_information.IndividualOwner.postal_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_city', full_name='willowlabs.services.company_information.IndividualOwner.postal_city', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_share', full_name='willowlabs.services.company_information.IndividualOwner.percent_share', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equivalent_shares', full_name='willowlabs.services.company_information.IndividualOwner.equivalent_shares', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_depth', full_name='willowlabs.services.company_information.IndividualOwner.min_depth', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_depth', full_name='willowlabs.services.company_information.IndividualOwner.max_depth', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direct_ownership', full_name='willowlabs.services.company_information.IndividualOwner.direct_ownership', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=530,
)


_UNKNOWNOWNER = _descriptor.Descriptor(
  name='UnknownOwner',
  full_name='willowlabs.services.company_information.UnknownOwner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='willowlabs.services.company_information.UnknownOwner.postal_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_city', full_name='willowlabs.services.company_information.UnknownOwner.postal_city', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_share', full_name='willowlabs.services.company_information.UnknownOwner.percent_share', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equivalent_shares', full_name='willowlabs.services.company_information.UnknownOwner.equivalent_shares', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direct_ownership', full_name='willowlabs.services.company_information.UnknownOwner.direct_ownership', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=723,
)


_OWNERSHIPREQUEST = _descriptor.Descriptor(
  name='OwnershipRequest',
  full_name='willowlabs.services.company_information.OwnershipRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organisation_number', full_name='willowlabs.services.company_information.OwnershipRequest.organisation_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='record_year', full_name='willowlabs.services.company_information.OwnershipRequest.record_year', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cutoff', full_name='willowlabs.services.company_information.OwnershipRequest.cutoff', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depth', full_name='willowlabs.services.company_information.OwnershipRequest.depth', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top', full_name='willowlabs.services.company_information.OwnershipRequest.top', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exhaustive', full_name='willowlabs.services.company_information.OwnershipRequest.exhaustive', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=858,
)


_COMPANYSHARES = _descriptor.Descriptor(
  name='CompanyShares',
  full_name='willowlabs.services.company_information.CompanyShares',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organisation_number', full_name='willowlabs.services.company_information.CompanyShares.organisation_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='company_name', full_name='willowlabs.services.company_information.CompanyShares.company_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isin', full_name='willowlabs.services.company_information.CompanyShares.isin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_shares', full_name='willowlabs.services.company_information.CompanyShares.total_shares', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='individual_owners', full_name='willowlabs.services.company_information.CompanyShares.individual_owners', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknown_owners', full_name='willowlabs.services.company_information.CompanyShares.unknown_owners', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exhaustive', full_name='willowlabs.services.company_information.CompanyShares.exhaustive', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=1147,
)


_OWNERSHIPRESPONSE = _descriptor.Descriptor(
  name='OwnershipResponse',
  full_name='willowlabs.services.company_information.OwnershipResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='willowlabs.services.company_information.OwnershipResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='company_shares', full_name='willowlabs.services.company_information.OwnershipResponse.company_shares', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bad_request', full_name='willowlabs.services.company_information.OwnershipResponse.bad_request', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_error', full_name='willowlabs.services.company_information.OwnershipResponse.server_error', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_timestamp', full_name='willowlabs.services.company_information.OwnershipResponse.response_timestamp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1150,
  serialized_end=1424,
)


_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='willowlabs.services.company_information.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='willowlabs.services.company_information.Date.year', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='month', full_name='willowlabs.services.company_information.Date.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='day', full_name='willowlabs.services.company_information.Date.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1426,
  serialized_end=1474,
)


_ROLEREQUEST = _descriptor.Descriptor(
  name='RoleRequest',
  full_name='willowlabs.services.company_information.RoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organisation_number', full_name='willowlabs.services.company_information.RoleRequest.organisation_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_date', full_name='willowlabs.services.company_information.RoleRequest.query_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1585,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='willowlabs.services.company_information.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='street_address', full_name='willowlabs.services.company_information.Address.street_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='city', full_name='willowlabs.services.company_information.Address.city', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='willowlabs.services.company_information.Address.postal_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country', full_name='willowlabs.services.company_information.Address.country', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1672,
)


_COMPANYOFFICER = _descriptor.Descriptor(
  name='CompanyOfficer',
  full_name='willowlabs.services.company_information.CompanyOfficer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='willowlabs.services.company_information.CompanyOfficer.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='birth_year', full_name='willowlabs.services.company_information.CompanyOfficer.birth_year', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_of_birth', full_name='willowlabs.services.company_information.CompanyOfficer.date_of_birth', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organisation_number', full_name='willowlabs.services.company_information.CompanyOfficer.organisation_number', index=3,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='willowlabs.services.company_information.CompanyOfficer.address', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='willowlabs.services.company_information.CompanyOfficer.role', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='special_role', full_name='willowlabs.services.company_information.CompanyOfficer.special_role', index=6,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role_action', full_name='willowlabs.services.company_information.CompanyOfficer.role_action', index=7,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='announcement_date', full_name='willowlabs.services.company_information.CompanyOfficer.announcement_date', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_person', full_name='willowlabs.services.company_information.CompanyOfficer.is_person', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bad_date_of_birth', full_name='willowlabs.services.company_information.CompanyOfficer.bad_date_of_birth', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_date_string', full_name='willowlabs.services.company_information.CompanyOfficer.raw_date_string', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=2247,
)


_ROLERESPONSE = _descriptor.Descriptor(
  name='RoleResponse',
  full_name='willowlabs.services.company_information.RoleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='willowlabs.services.company_information.RoleResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='officers', full_name='willowlabs.services.company_information.RoleResponse.officers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='complete_ceo_search', full_name='willowlabs.services.company_information.RoleResponse.complete_ceo_search', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='complete_board_search', full_name='willowlabs.services.company_information.RoleResponse.complete_board_search', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bad_request', full_name='willowlabs.services.company_information.RoleResponse.bad_request', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_error', full_name='willowlabs.services.company_information.RoleResponse.server_error', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_timestamp', full_name='willowlabs.services.company_information.RoleResponse.response_timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2250,
  serialized_end=2569,
)


_SECTORCODE = _descriptor.Descriptor(
  name='SectorCode',
  full_name='willowlabs.services.company_information.SectorCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='willowlabs.services.company_information.SectorCode.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_en', full_name='willowlabs.services.company_information.SectorCode.description_en', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_nb', full_name='willowlabs.services.company_information.SectorCode.description_nb', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2571,
  serialized_end=2645,
)


_NACECODE = _descriptor.Descriptor(
  name='NACECode',
  full_name='willowlabs.services.company_information.NACECode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='willowlabs.services.company_information.NACECode.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_en', full_name='willowlabs.services.company_information.NACECode.description_en', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_nb', full_name='willowlabs.services.company_information.NACECode.description_nb', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level1_code', full_name='willowlabs.services.company_information.NACECode.level1_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level1_description_en', full_name='willowlabs.services.company_information.NACECode.level1_description_en', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level1_description_nb', full_name='willowlabs.services.company_information.NACECode.level1_description_nb', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level2_code', full_name='willowlabs.services.company_information.NACECode.level2_code', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level2_description_en', full_name='willowlabs.services.company_information.NACECode.level2_description_en', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level2_description_nb', full_name='willowlabs.services.company_information.NACECode.level2_description_nb', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level3_code', full_name='willowlabs.services.company_information.NACECode.level3_code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level3_description_en', full_name='willowlabs.services.company_information.NACECode.level3_description_en', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level3_description_nb', full_name='willowlabs.services.company_information.NACECode.level3_description_nb', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level4_code', full_name='willowlabs.services.company_information.NACECode.level4_code', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level4_description_en', full_name='willowlabs.services.company_information.NACECode.level4_description_en', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level4_description_nb', full_name='willowlabs.services.company_information.NACECode.level4_description_nb', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2648,
  serialized_end=3052,
)


_COMPANYTYPE = _descriptor.Descriptor(
  name='CompanyType',
  full_name='willowlabs.services.company_information.CompanyType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='willowlabs.services.company_information.CompanyType.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_en', full_name='willowlabs.services.company_information.CompanyType.description_en', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_nb', full_name='willowlabs.services.company_information.CompanyType.description_nb', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3054,
  serialized_end=3129,
)


_NONPROFITREGISTRATION = _descriptor.Descriptor(
  name='NonprofitRegistration',
  full_name='willowlabs.services.company_information.NonprofitRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='registered_as_nonprofit', full_name='willowlabs.services.company_information.NonprofitRegistration.registered_as_nonprofit', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vat_registration_description_en', full_name='willowlabs.services.company_information.NonprofitRegistration.vat_registration_description_en', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vat_registration_description_nb', full_name='willowlabs.services.company_information.NonprofitRegistration.vat_registration_description_nb', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3132,
  serialized_end=3270,
)


_COMPANYADDRESS = _descriptor.Descriptor(
  name='CompanyAddress',
  full_name='willowlabs.services.company_information.CompanyAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='street_address', full_name='willowlabs.services.company_information.CompanyAddress.street_address', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='city', full_name='willowlabs.services.company_information.CompanyAddress.city', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='willowlabs.services.company_information.CompanyAddress.postal_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='county', full_name='willowlabs.services.company_information.CompanyAddress.county', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='county_number', full_name='willowlabs.services.company_information.CompanyAddress.county_number', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country', full_name='willowlabs.services.company_information.CompanyAddress.country', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='willowlabs.services.company_information.CompanyAddress.country_code', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3273,
  serialized_end=3426,
)


_BASICCOMPANYINFORMATION = _descriptor.Descriptor(
  name='BasicCompanyInformation',
  full_name='willowlabs.services.company_information.BasicCompanyInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organisation_number', full_name='willowlabs.services.company_information.BasicCompanyInformation.organisation_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='company_name', full_name='willowlabs.services.company_information.BasicCompanyInformation.company_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='founded_date', full_name='willowlabs.services.company_information.BasicCompanyInformation.founded_date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registration_date', full_name='willowlabs.services.company_information.BasicCompanyInformation.registration_date', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='company_type', full_name='willowlabs.services.company_information.BasicCompanyInformation.company_type', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='website', full_name='willowlabs.services.company_information.BasicCompanyInformation.website', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonprofit_registration', full_name='willowlabs.services.company_information.BasicCompanyInformation.nonprofit_registration', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registered_in_vat_registry', full_name='willowlabs.services.company_information.BasicCompanyInformation.registered_in_vat_registry', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registered_in_business_registry', full_name='willowlabs.services.company_information.BasicCompanyInformation.registered_in_business_registry', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registered_in_foundation_registry', full_name='willowlabs.services.company_information.BasicCompanyInformation.registered_in_foundation_registry', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_employees', full_name='willowlabs.services.company_information.BasicCompanyInformation.number_of_employees', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='institutional_sector_code', full_name='willowlabs.services.company_information.BasicCompanyInformation.institutional_sector_code', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='industry_code_1', full_name='willowlabs.services.company_information.BasicCompanyInformation.industry_code_1', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='industry_code_2', full_name='willowlabs.services.company_information.BasicCompanyInformation.industry_code_2', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='industry_code_3', full_name='willowlabs.services.company_information.BasicCompanyInformation.industry_code_3', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postal_address', full_name='willowlabs.services.company_information.BasicCompanyInformation.postal_address', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_address', full_name='willowlabs.services.company_information.BasicCompanyInformation.business_address', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_submitted_annual_accounts', full_name='willowlabs.services.company_information.BasicCompanyInformation.last_submitted_annual_accounts', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bankrupt', full_name='willowlabs.services.company_information.BasicCompanyInformation.bankrupt', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='under_liquidation', full_name='willowlabs.services.company_information.BasicCompanyInformation.under_liquidation', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='under_forced_liquidation_or_dissolution', full_name='willowlabs.services.company_information.BasicCompanyInformation.under_forced_liquidation_or_dissolution', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_company', full_name='willowlabs.services.company_information.BasicCompanyInformation.parent_company', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='willowlabs.services.company_information.BasicCompanyInformation.language', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commencement_date', full_name='willowlabs.services.company_information.BasicCompanyInformation.commencement_date', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closure_date', full_name='willowlabs.services.company_information.BasicCompanyInformation.closure_date', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ownership_date', full_name='willowlabs.services.company_information.BasicCompanyInformation.ownership_date', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_address', full_name='willowlabs.services.company_information.BasicCompanyInformation.location_address', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='record_first_retrieved', full_name='willowlabs.services.company_information.BasicCompanyInformation.record_first_retrieved', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='most_recent_record', full_name='willowlabs.services.company_information.BasicCompanyInformation.most_recent_record', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3429,
  serialized_end=5046,
)


_BASICCOMPANYINFORMATIONREQUEST = _descriptor.Descriptor(
  name='BasicCompanyInformationRequest',
  full_name='willowlabs.services.company_information.BasicCompanyInformationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organisation_number', full_name='willowlabs.services.company_information.BasicCompanyInformationRequest.organisation_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_date', full_name='willowlabs.services.company_information.BasicCompanyInformationRequest.query_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5049,
  serialized_end=5177,
)


_BASICCOMPANYINFORMATIONRESPONSE = _descriptor.Descriptor(
  name='BasicCompanyInformationResponse',
  full_name='willowlabs.services.company_information.BasicCompanyInformationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='willowlabs.services.company_information.BasicCompanyInformationResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='basic_company_information', full_name='willowlabs.services.company_information.BasicCompanyInformationResponse.basic_company_information', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bad_request', full_name='willowlabs.services.company_information.BasicCompanyInformationResponse.bad_request', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_error', full_name='willowlabs.services.company_information.BasicCompanyInformationResponse.server_error', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_timestamp', full_name='willowlabs.services.company_information.BasicCompanyInformationResponse.response_timestamp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5180,
  serialized_end=5503,
)


_SIGNATORYINDIVIDUAL = _descriptor.Descriptor(
  name='SignatoryIndividual',
  full_name='willowlabs.services.company_information.SignatoryIndividual',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='willowlabs.services.company_information.SignatoryIndividual.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_of_birth', full_name='willowlabs.services.company_information.SignatoryIndividual.date_of_birth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5505,
  serialized_end=5610,
)


_SIGNATORYINFORMATIONREQUEST = _descriptor.Descriptor(
  name='SignatoryInformationRequest',
  full_name='willowlabs.services.company_information.SignatoryInformationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organisation_number', full_name='willowlabs.services.company_information.SignatoryInformationRequest.organisation_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authority_type', full_name='willowlabs.services.company_information.SignatoryInformationRequest.authority_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_date', full_name='willowlabs.services.company_information.SignatoryInformationRequest.query_date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5613,
  serialized_end=5828,
)


_AUTHORIZEDSIGNATURE = _descriptor.Descriptor(
  name='AuthorizedSignature',
  full_name='willowlabs.services.company_information.AuthorizedSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signatory_text_nb', full_name='willowlabs.services.company_information.AuthorizedSignature.signatory_text_nb', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signatory_text_en', full_name='willowlabs.services.company_information.AuthorizedSignature.signatory_text_en', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='willowlabs.services.company_information.AuthorizedSignature.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorized_individual', full_name='willowlabs.services.company_information.AuthorizedSignature.authorized_individual', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5831,
  serialized_end=6013,
)


_SIGNATORYINFORMATIONRESPONSE = _descriptor.Descriptor(
  name='SignatoryInformationResponse',
  full_name='willowlabs.services.company_information.SignatoryInformationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='willowlabs.services.company_information.SignatoryInformationResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorized_signatures', full_name='willowlabs.services.company_information.SignatoryInformationResponse.authorized_signatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_signatory_text', full_name='willowlabs.services.company_information.SignatoryInformationResponse.raw_signatory_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_signatory_records_found', full_name='willowlabs.services.company_information.SignatoryInformationResponse.no_signatory_records_found', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fallback_results', full_name='willowlabs.services.company_information.SignatoryInformationResponse.fallback_results', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bad_request', full_name='willowlabs.services.company_information.SignatoryInformationResponse.bad_request', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_error', full_name='willowlabs.services.company_information.SignatoryInformationResponse.server_error', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_timestamp', full_name='willowlabs.services.company_information.SignatoryInformationResponse.response_timestamp', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6016,
  serialized_end=6415,
)

_DIRECTOWNERSHIP.fields_by_name['share_class'].enum_type = _SHARECLASS
_INDIVIDUALOWNER.fields_by_name['direct_ownership'].message_type = _DIRECTOWNERSHIP
_UNKNOWNOWNER.fields_by_name['direct_ownership'].message_type = _DIRECTOWNERSHIP
_COMPANYSHARES.fields_by_name['individual_owners'].message_type = _INDIVIDUALOWNER
_COMPANYSHARES.fields_by_name['unknown_owners'].message_type = _UNKNOWNOWNER
_OWNERSHIPRESPONSE.fields_by_name['request'].message_type = _OWNERSHIPREQUEST
_OWNERSHIPRESPONSE.fields_by_name['company_shares'].message_type = _COMPANYSHARES
_OWNERSHIPRESPONSE.fields_by_name['response_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROLEREQUEST.fields_by_name['query_date'].message_type = _DATE
_COMPANYOFFICER.fields_by_name['date_of_birth'].message_type = _DATE
_COMPANYOFFICER.fields_by_name['address'].message_type = _ADDRESS
_COMPANYOFFICER.fields_by_name['role'].enum_type = _ROLE
_COMPANYOFFICER.fields_by_name['special_role'].enum_type = _SPECIALROLE
_COMPANYOFFICER.fields_by_name['role_action'].enum_type = _ROLEACTION
_COMPANYOFFICER.fields_by_name['announcement_date'].message_type = _DATE
_ROLERESPONSE.fields_by_name['request'].message_type = _ROLEREQUEST
_ROLERESPONSE.fields_by_name['officers'].message_type = _COMPANYOFFICER
_ROLERESPONSE.fields_by_name['response_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BASICCOMPANYINFORMATION.fields_by_name['founded_date'].message_type = _DATE
_BASICCOMPANYINFORMATION.fields_by_name['registration_date'].message_type = _DATE
_BASICCOMPANYINFORMATION.fields_by_name['company_type'].message_type = _COMPANYTYPE
_BASICCOMPANYINFORMATION.fields_by_name['nonprofit_registration'].message_type = _NONPROFITREGISTRATION
_BASICCOMPANYINFORMATION.fields_by_name['institutional_sector_code'].message_type = _SECTORCODE
_BASICCOMPANYINFORMATION.fields_by_name['industry_code_1'].message_type = _NACECODE
_BASICCOMPANYINFORMATION.fields_by_name['industry_code_2'].message_type = _NACECODE
_BASICCOMPANYINFORMATION.fields_by_name['industry_code_3'].message_type = _NACECODE
_BASICCOMPANYINFORMATION.fields_by_name['postal_address'].message_type = _COMPANYADDRESS
_BASICCOMPANYINFORMATION.fields_by_name['business_address'].message_type = _COMPANYADDRESS
_BASICCOMPANYINFORMATION.fields_by_name['commencement_date'].message_type = _DATE
_BASICCOMPANYINFORMATION.fields_by_name['closure_date'].message_type = _DATE
_BASICCOMPANYINFORMATION.fields_by_name['ownership_date'].message_type = _DATE
_BASICCOMPANYINFORMATION.fields_by_name['location_address'].message_type = _COMPANYADDRESS
_BASICCOMPANYINFORMATION.fields_by_name['record_first_retrieved'].message_type = _DATE
_BASICCOMPANYINFORMATIONREQUEST.fields_by_name['query_date'].message_type = _DATE
_BASICCOMPANYINFORMATIONRESPONSE.fields_by_name['request'].message_type = _BASICCOMPANYINFORMATIONREQUEST
_BASICCOMPANYINFORMATIONRESPONSE.fields_by_name['basic_company_information'].message_type = _BASICCOMPANYINFORMATION
_BASICCOMPANYINFORMATIONRESPONSE.fields_by_name['response_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SIGNATORYINDIVIDUAL.fields_by_name['date_of_birth'].message_type = _DATE
_SIGNATORYINFORMATIONREQUEST.fields_by_name['authority_type'].enum_type = _SIGNATORYAUTHORITYTYPES
_SIGNATORYINFORMATIONREQUEST.fields_by_name['query_date'].message_type = _DATE
_AUTHORIZEDSIGNATURE.fields_by_name['authorized_individual'].message_type = _SIGNATORYINDIVIDUAL
_SIGNATORYINFORMATIONRESPONSE.fields_by_name['request'].message_type = _SIGNATORYINFORMATIONREQUEST
_SIGNATORYINFORMATIONRESPONSE.fields_by_name['authorized_signatures'].message_type = _AUTHORIZEDSIGNATURE
_SIGNATORYINFORMATIONRESPONSE.fields_by_name['response_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['DirectOwnership'] = _DIRECTOWNERSHIP
DESCRIPTOR.message_types_by_name['IndividualOwner'] = _INDIVIDUALOWNER
DESCRIPTOR.message_types_by_name['UnknownOwner'] = _UNKNOWNOWNER
DESCRIPTOR.message_types_by_name['OwnershipRequest'] = _OWNERSHIPREQUEST
DESCRIPTOR.message_types_by_name['CompanyShares'] = _COMPANYSHARES
DESCRIPTOR.message_types_by_name['OwnershipResponse'] = _OWNERSHIPRESPONSE
DESCRIPTOR.message_types_by_name['Date'] = _DATE
DESCRIPTOR.message_types_by_name['RoleRequest'] = _ROLEREQUEST
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['CompanyOfficer'] = _COMPANYOFFICER
DESCRIPTOR.message_types_by_name['RoleResponse'] = _ROLERESPONSE
DESCRIPTOR.message_types_by_name['SectorCode'] = _SECTORCODE
DESCRIPTOR.message_types_by_name['NACECode'] = _NACECODE
DESCRIPTOR.message_types_by_name['CompanyType'] = _COMPANYTYPE
DESCRIPTOR.message_types_by_name['NonprofitRegistration'] = _NONPROFITREGISTRATION
DESCRIPTOR.message_types_by_name['CompanyAddress'] = _COMPANYADDRESS
DESCRIPTOR.message_types_by_name['BasicCompanyInformation'] = _BASICCOMPANYINFORMATION
DESCRIPTOR.message_types_by_name['BasicCompanyInformationRequest'] = _BASICCOMPANYINFORMATIONREQUEST
DESCRIPTOR.message_types_by_name['BasicCompanyInformationResponse'] = _BASICCOMPANYINFORMATIONRESPONSE
DESCRIPTOR.message_types_by_name['SignatoryIndividual'] = _SIGNATORYINDIVIDUAL
DESCRIPTOR.message_types_by_name['SignatoryInformationRequest'] = _SIGNATORYINFORMATIONREQUEST
DESCRIPTOR.message_types_by_name['AuthorizedSignature'] = _AUTHORIZEDSIGNATURE
DESCRIPTOR.message_types_by_name['SignatoryInformationResponse'] = _SIGNATORYINFORMATIONRESPONSE
DESCRIPTOR.enum_types_by_name['ShareClass'] = _SHARECLASS
DESCRIPTOR.enum_types_by_name['Role'] = _ROLE
DESCRIPTOR.enum_types_by_name['SpecialRole'] = _SPECIALROLE
DESCRIPTOR.enum_types_by_name['RoleAction'] = _ROLEACTION
DESCRIPTOR.enum_types_by_name['SignatoryAuthorityTypes'] = _SIGNATORYAUTHORITYTYPES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DirectOwnership = _reflection.GeneratedProtocolMessageType('DirectOwnership', (_message.Message,), {
  'DESCRIPTOR' : _DIRECTOWNERSHIP,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.DirectOwnership)
  })
_sym_db.RegisterMessage(DirectOwnership)

IndividualOwner = _reflection.GeneratedProtocolMessageType('IndividualOwner', (_message.Message,), {
  'DESCRIPTOR' : _INDIVIDUALOWNER,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.IndividualOwner)
  })
_sym_db.RegisterMessage(IndividualOwner)

UnknownOwner = _reflection.GeneratedProtocolMessageType('UnknownOwner', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNOWNER,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.UnknownOwner)
  })
_sym_db.RegisterMessage(UnknownOwner)

OwnershipRequest = _reflection.GeneratedProtocolMessageType('OwnershipRequest', (_message.Message,), {
  'DESCRIPTOR' : _OWNERSHIPREQUEST,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.OwnershipRequest)
  })
_sym_db.RegisterMessage(OwnershipRequest)

CompanyShares = _reflection.GeneratedProtocolMessageType('CompanyShares', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYSHARES,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.CompanyShares)
  })
_sym_db.RegisterMessage(CompanyShares)

OwnershipResponse = _reflection.GeneratedProtocolMessageType('OwnershipResponse', (_message.Message,), {
  'DESCRIPTOR' : _OWNERSHIPRESPONSE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.OwnershipResponse)
  })
_sym_db.RegisterMessage(OwnershipResponse)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
  'DESCRIPTOR' : _DATE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.Date)
  })
_sym_db.RegisterMessage(Date)

RoleRequest = _reflection.GeneratedProtocolMessageType('RoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEREQUEST,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.RoleRequest)
  })
_sym_db.RegisterMessage(RoleRequest)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.Address)
  })
_sym_db.RegisterMessage(Address)

CompanyOfficer = _reflection.GeneratedProtocolMessageType('CompanyOfficer', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYOFFICER,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.CompanyOfficer)
  })
_sym_db.RegisterMessage(CompanyOfficer)

RoleResponse = _reflection.GeneratedProtocolMessageType('RoleResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLERESPONSE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.RoleResponse)
  })
_sym_db.RegisterMessage(RoleResponse)

SectorCode = _reflection.GeneratedProtocolMessageType('SectorCode', (_message.Message,), {
  'DESCRIPTOR' : _SECTORCODE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.SectorCode)
  })
_sym_db.RegisterMessage(SectorCode)

NACECode = _reflection.GeneratedProtocolMessageType('NACECode', (_message.Message,), {
  'DESCRIPTOR' : _NACECODE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.NACECode)
  })
_sym_db.RegisterMessage(NACECode)

CompanyType = _reflection.GeneratedProtocolMessageType('CompanyType', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYTYPE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.CompanyType)
  })
_sym_db.RegisterMessage(CompanyType)

NonprofitRegistration = _reflection.GeneratedProtocolMessageType('NonprofitRegistration', (_message.Message,), {
  'DESCRIPTOR' : _NONPROFITREGISTRATION,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.NonprofitRegistration)
  })
_sym_db.RegisterMessage(NonprofitRegistration)

CompanyAddress = _reflection.GeneratedProtocolMessageType('CompanyAddress', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYADDRESS,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.CompanyAddress)
  })
_sym_db.RegisterMessage(CompanyAddress)

BasicCompanyInformation = _reflection.GeneratedProtocolMessageType('BasicCompanyInformation', (_message.Message,), {
  'DESCRIPTOR' : _BASICCOMPANYINFORMATION,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.BasicCompanyInformation)
  })
_sym_db.RegisterMessage(BasicCompanyInformation)

BasicCompanyInformationRequest = _reflection.GeneratedProtocolMessageType('BasicCompanyInformationRequest', (_message.Message,), {
  'DESCRIPTOR' : _BASICCOMPANYINFORMATIONREQUEST,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.BasicCompanyInformationRequest)
  })
_sym_db.RegisterMessage(BasicCompanyInformationRequest)

BasicCompanyInformationResponse = _reflection.GeneratedProtocolMessageType('BasicCompanyInformationResponse', (_message.Message,), {
  'DESCRIPTOR' : _BASICCOMPANYINFORMATIONRESPONSE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.BasicCompanyInformationResponse)
  })
_sym_db.RegisterMessage(BasicCompanyInformationResponse)

SignatoryIndividual = _reflection.GeneratedProtocolMessageType('SignatoryIndividual', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATORYINDIVIDUAL,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.SignatoryIndividual)
  })
_sym_db.RegisterMessage(SignatoryIndividual)

SignatoryInformationRequest = _reflection.GeneratedProtocolMessageType('SignatoryInformationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATORYINFORMATIONREQUEST,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.SignatoryInformationRequest)
  })
_sym_db.RegisterMessage(SignatoryInformationRequest)

AuthorizedSignature = _reflection.GeneratedProtocolMessageType('AuthorizedSignature', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZEDSIGNATURE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.AuthorizedSignature)
  })
_sym_db.RegisterMessage(AuthorizedSignature)

SignatoryInformationResponse = _reflection.GeneratedProtocolMessageType('SignatoryInformationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATORYINFORMATIONRESPONSE,
  '__module__' : 'willowlabs.service_grpc.company_information.company_information_service_pb2'
  # @@protoc_insertion_point(class_scope:willowlabs.services.company_information.SignatoryInformationResponse)
  })
_sym_db.RegisterMessage(SignatoryInformationResponse)



_COMPANYINFORMATION = _descriptor.ServiceDescriptor(
  name='CompanyInformation',
  full_name='willowlabs.services.company_information.CompanyInformation',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=7285,
  serialized_end=7949,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_company_ownership',
    full_name='willowlabs.services.company_information.CompanyInformation.get_company_ownership',
    index=0,
    containing_service=None,
    input_type=_OWNERSHIPREQUEST,
    output_type=_OWNERSHIPRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_roles',
    full_name='willowlabs.services.company_information.CompanyInformation.get_company_roles',
    index=1,
    containing_service=None,
    input_type=_ROLEREQUEST,
    output_type=_ROLERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_basic_company_information',
    full_name='willowlabs.services.company_information.CompanyInformation.get_basic_company_information',
    index=2,
    containing_service=None,
    input_type=_BASICCOMPANYINFORMATIONREQUEST,
    output_type=_BASICCOMPANYINFORMATIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_signatory_information',
    full_name='willowlabs.services.company_information.CompanyInformation.get_company_signatory_information',
    index=3,
    containing_service=None,
    input_type=_SIGNATORYINFORMATIONREQUEST,
    output_type=_SIGNATORYINFORMATIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMPANYINFORMATION)

DESCRIPTOR.services_by_name['CompanyInformation'] = _COMPANYINFORMATION

# @@protoc_insertion_point(module_scope)



import os
import time
import yaml
import google.auth.crypt
import google.auth.jwt
from itertools import product
from typing import Dict, Tuple, Union
from google.oauth2.service_account import Credentials
from google.auth.impersonated_credentials import Credentials as ImpersonatedCredentials
from google.auth.transport.requests import Request
from google.auth.iam import Signer

MAX_TOKEN_LIFETIME_SECS = 12 * 3600  # seconds
CONFIG_TYPE = Dict[str, Union[str, Dict[str, str]]]


def load_client_configuration(configuration_path: str) -> CONFIG_TYPE:
    """
    This reads the configuration file in yaml format and returns the configuration as a dictionary.
    It also validates the format of the configuration to ensure all the necessary fields are present.
    :param configuration_path: The location of the configuration file.
    :type configuration_path: str
    :return: The parsed configuration.
    :rtype: Dict[str, Union[str, Dict[str, str]]]
    :raises: KeyError, TypeError, FileNotFoundError
    """
    if os.path.exists(configuration_path):
        if configuration_path.endswith(".yaml") or configuration_path.endswith(".yml") or \
                configuration_path.endswith(".json"):
            with open(configuration_path, "r") as stream:
                configuration = yaml.safe_load(stream)
            svc_config = configuration.get("service")
            if svc_config is not None and \
                    all(j in svc_config and k in svc_config[j]
                        for j, k in product(["production", "development"],
                                            ["host", "api_key", "service_account_credentials", "authentication"])):
                return configuration
            raise KeyError("load_client_configuration: Configuration file is missing keys.")
        raise TypeError(f"load_client_configuration: The configuration file must be a yaml file or a json file "
                        f"with extensions '.yaml', '.yml', or '.json'.  The configuration path given was "
                        f"{configuration_path}")
    raise FileNotFoundError(f"load_configuration: The file {configuration_path} does not exist!")


def generate_jwt_token_from_impersonated_account(service_account_info: Dict[str, str], audiences: str,
                                                 issuer: str) -> Tuple[str, int]:
    """
    Using a dictionary containing the information from a Google Cloud service account credentials file, this function
    impersonates the Company Information API master user service account and signs a JSON Web Token (JWT) used to
    authenticate the client when accessing the service.
    :param service_account_info: A dictionary containing all the information found in a Google Cloud service account
    credentials JSON file.
    :type service_account_info: Dict[str, str]
    :param audiences: The intended recipient of the JWT. Found in the Google Endpoint specification. For example,
    for the company information API, the recipient is 'company-information.api.willowlabs.ai'
    :type audiences: str
    :param issuer: The email address of the impersonated API master user service account.
    :type issuer: str
    :param jwt_lifetime: The length of time, in seconds, for which the created JWT is valid.
    :type jwt_lifetime: int
    :return: A tuple containing the JWT and a POSIX/Unix epoch-style timestamp indicating when the JWT expires.
    :rtype: Tuple[str, int]
    """
    credentials = Credentials.from_service_account_info(service_account_info,
                                                        scopes=["https://www.googleapis.com/auth/cloud-platform",
                                                                "https://www.googleapis.com/auth/iam"])
    if not credentials.valid:
        credentials.refresh(Request())
    impersonated_credentials = ImpersonatedCredentials(source_credentials=credentials, target_principal=issuer,
                                                       target_scopes=["https://www.googleapis.com/auth/cloud-platform",
                                                                      "https://www.googleapis.com/auth/iam"])
    if not impersonated_credentials.valid:
        impersonated_credentials.refresh(Request())

    signer = Signer(Request(), impersonated_credentials, impersonated_credentials.service_account_email)
    now = int(time.time())
    expires = now + MAX_TOKEN_LIFETIME_SECS

    payload = {
        'iat': now,
        'exp': expires,
        'aud': audiences,
        'iss': issuer
    }
    return google.auth.jwt.encode(signer, payload).decode("utf-8"), expires



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from willowlabs.service_grpc.company_information import company_information_service_pb2 as willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2


class CompanyInformationStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.get_company_ownership = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_company_ownership',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipResponse.FromString,
        )
    self.get_company_roles = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_company_roles',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleResponse.FromString,
        )
    self.get_basic_company_information = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_basic_company_information',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationResponse.FromString,
        )
    self.get_company_signatory_information = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_company_signatory_information',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationResponse.FromString,
        )


class CompanyInformationServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def get_company_ownership(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_roles(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_basic_company_information(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_signatory_information(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CompanyInformationServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'get_company_ownership': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_ownership,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipResponse.SerializeToString,
      ),
      'get_company_roles': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_roles,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleResponse.SerializeToString,
      ),
      'get_basic_company_information': grpc.unary_unary_rpc_method_handler(
          servicer.get_basic_company_information,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationResponse.SerializeToString,
      ),
      'get_company_signatory_information': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_signatory_information,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'willowlabs.services.company_information.CompanyInformation', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# py.tests  -v --junitxml="result.xml"

import pytest
import yaml

from willowlabs.company_information.client import CompanyInformationClient


# import mock
# from pytest_mock import mocker


def tmp_client():
    with open(r"config-dev.yaml") as file:
        # The FullLoader parameter handles the conversion from YAML
        # scalar values to Python the dictionary format
        config = yaml.load(file, Loader=yaml.FullLoader)
    client = CompanyInformationClient(config["client_config_path"])
    return client


@pytest.fixture
def client():
    with open(r"config-dev.yaml") as file:
        # The FullLoader parameter handles the conversion from YAML
        # scalar values to Python the dictionary format
        config = yaml.load(file, Loader=yaml.FullLoader)
    client = CompanyInformationClient(config["client_config_path"])
    return client


def test_get_basic_company_information_failure_1(client):
    organisation_number = 1
    company_basic_results = client.get_basic_company_information(organisation_number)
    assert company_basic_results.bad_request


def test_get_basic_company_information_beaufort_1(client):
    organisation_number = 923710809
    company_basic_results = client.get_basic_company_information(organisation_number)
    print(company_basic_results)
    assert (
        company_basic_results.basic_company_information.company_name
        == "BEAUFORT SOLUTIONS AS"
    )
    print(company_basic_results.basic_company_information.company_name)


def test_get_company_ownership_beaufort_failure_1(client):
    organisation_number = 1
    record_year = 2018
    company_ownership_results = client.get_company_ownership(
        organisation_number, record_year
    )
    assert company_ownership_results.bad_request


def test_get_company_ownership_beaufort_success(client):
    record_year = 2018
    organisation_number = 923710809
    company_ownership_results = client.get_company_ownership(
        organisation_number, record_year
    )
    assert not company_ownership_results.bad_request


def test_get_company_ownership_beaufort_struture_ok_1(client):
    record_year = 2018
    organisation_number = 913174054
    cutoff = 1
    depth = 2
    company_ownership_results = client.get_company_ownership(
        organisation_number, record_year, depth, cutoff
    )
    print(company_ownership_results)
    print(type(company_ownership_results))
    print(len(company_ownership_results.company_shares[0].individual_owners))
    assert len(company_ownership_results.company_shares[0].individual_owners) == 2


def test_get_company_power_of_attorney_ok_1(client):
    # record_year = 2018
    organisation_number = 913174054
    company_poa_results = client.get_company_power_of_attorney(organisation_number)
    print(company_poa_results)
    assert (
        company_poa_results.authorized_signatures[0].signatory_text_en
        == "Board chairman alone"
    )


test_get_company_power_of_attorney_ok_1(tmp_client())



# -*- coding: utf-8 -*-
# Copyright 2020 Willow Labs AS. All rights reserved.

try:
    __import__("pkg_resources").declare_namespace(__name__)
except ImportError:
    __path__ = __import__("pkgutil").extend_path(__path__, __name__)

__version__ = "0.7.0"
